@@ -149,6 +149,31 @@ def _writePluginParamField(folder, element, NewParamValueDictionary, hubName):
 	db.query_rowcount(sql, data)
 
 
+def _writeModuleParamField(module, NewParamValueDictionary, hubName):
+        """
+        Take a dictionary, transform it to properly formatted params string for Joomla, and 
+        update the params field of the jos_extensions table for the specified plugin
+        """
+        # database config
+        dbPW = getWebConfigDBPassword(hubName)
+        dbUserName = getWebConfigDBUsername(hubName)
+        dbName = getWebConfigDBName(hubName)
+        db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+
+        if hubzero.utilities.misc.JOOMLA_25:
+                parmString = json.dumps(NewParamValueDictionary)
+                sql = "UPDATE `jos_modules` SET `params`=%s WHERE `title`=%s"
+        else:
+                parmString = ""
+                for parm in NewParamValueDictionary:
+                        parmString += parm + "=" + NewParamValueDictionary[parm] + "\n"
+                sql = "UPDATE `jos_modules` SET `params`=%s WHERE `title`=%s"
+
+        data = (parmString, module)
+        db.query_rowcount(sql, data)
+
+
+
 def _buildDictionary(componentOption, hubName):
 	"""
 	Put the parameter string of the database into a dictionary
@@ -236,6 +261,47 @@ def _buildPluginDictionary(folder, element, hubName):
 	return parmsDict
 	
 
+def _buildModuleDictionary(module, hubName):
+        """
+        Put the parameter string of the database into a dictionary
+        String follows the format:
+        
+        param1=value1
+        param2=value2
+        param3=value3
+        
+        """
+        # database config
+        dbPW = getWebConfigDBPassword(hubName)
+        dbUserName = getWebConfigDBUsername(hubName)
+        dbName = getWebConfigDBName(hubName)
+        db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+
+        # look up parm string and parse it on newline, for each line, parse it further based on *first* '='
+        sql = "SELECT `params` from jos_modules WHERE title=%s"
+
+        data = (module)
+        paramsString = db.query_selectscalar(sql, data)
+
+        if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
+                try:
+                        parmsDict = json.loads(paramsString)
+                        return parmsDict
+                except:
+                        pass
+
+        parmsDict = {}
+
+        if paramsString:
+                parms = paramsString.split("\n")
+                for parmline in parms:
+                        if parmline: # in case of any blank lines in the params field
+                                n,v = parmline.split("=", 1)
+                                parmsDict[n] = v
+
+        return parmsDict
+
+
 def getComponentParam(componentOption, parameterName, hubName = ""):
 	"""
 	Get individual param value for a component and return to caller
@@ -293,6 +359,22 @@ def addPluginParam(folder, element, parameterName, parameterValue, allowOverwrit
 
 	_writePluginParamField(folder,element, paramDict, hubName)	
 
+def addModuleParam(module, parameterName, parameterValue, allowOverwrite=True, hubName = ""):
+	"""
+	Add value to the param string in the jos_components table for the specified component.
+	"""
+	paramDict = _buildPluginDictionary(module,hubName)
+
+	if allowOverwrite:
+		paramDict[parameterName] = parameterValue
+	else:
+		if paramDict.has_key(parameterName):
+			raise Exception("ERROR: addModuleParam called for existing parameter with allowOverwrite = false")
+		else:
+			paramDict[parameterName] = parameterValue
+
+	_writeModuleParamField(module, paramDict, hubName)	
+
 	
 def delComponentParam(componentOption, parameterName, hubName = ""):
 	"""
